@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: add.py 778 2007-06-20 18:32:21Z mikej06 $'
+__revision__ = '$Id: add.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published byp
@@ -171,7 +171,7 @@ def set_details(self, item=None):#{{{
 	if item.has_key('medium_id') and item['medium_id']:
 		pos = gutils.findKey(item['medium_id'], self.media_ids)
 	else:
-		pos = gutils.findKey(self.config.get('media', 0, section='defaults'), self.media_ids)
+		pos = gutils.findKey(int(self.config.get('media', 0, section='defaults')), self.media_ids)
 	if pos is not None:
 		w['media'].set_active(int(pos))
 	else:
@@ -180,7 +180,7 @@ def set_details(self, item=None):#{{{
 	if item.has_key('vcodec_id') and item['vcodec_id']:
 		pos = gutils.findKey(item['vcodec_id'], self.vcodecs_ids)
 	else:
-		pos = gutils.findKey(self.config.get('vcodec', 0, section='defaults'), self.vcodecs_ids)
+		pos = gutils.findKey(int(self.config.get('vcodec', 0, section='defaults')), self.vcodecs_ids)
 	if pos is not None:
 		w['vcodec'].set_active(int(pos))
 	else:
@@ -360,8 +360,18 @@ def update_movie(self):
 		# update main treelist
 		tmp_model.set_value(tmp_iter,0,'%004d' % int(movie.number))
 		tmp_model.set_value(tmp_iter,2, movie.o_title)
-		tmp_model.set_value(tmp_iter,3,	movie.title)
+		tmp_model.set_value(tmp_iter,3, movie.title)
 		tmp_model.set_value(tmp_iter,4, movie.director)
+		tmp_model.set_value(tmp_iter,5, movie.genre)
+		tmp_model.set_value(tmp_iter,6, movie.seen)
+		if movie.year is None:
+			tmp_model.set_value(tmp_iter,7, '')
+		else:
+			tmp_model.set_value(tmp_iter,7, movie.year)
+		if movie.runtime is None:
+			tmp_model.set_value(tmp_iter,8, '')
+		else:
+			tmp_model.set_value(tmp_iter,8, '%003d' % int(movie.runtime) + _(' min'))
 		# close add window
 		self.widgets['add']['window'].hide()
 		# refresh
@@ -420,6 +430,16 @@ def add_movie_db(self, close):
 	self.treemodel.set_value(myiter, 2, details['o_title'])
 	self.treemodel.set_value(myiter, 3, details['title'])
 	self.treemodel.set_value(myiter, 4, details['director'])
+	self.treemodel.set_value(myiter, 5, details['genre'])
+	self.treemodel.set_value(myiter, 6, details['seen'])
+	if details['year'] is None:
+		self.treemodel.set_value(myiter, 7, '')
+	else:
+		self.treemodel.set_value(myiter, 7, details['year'])
+	if details['runtime'] is None:
+		self.treemodel.set_value(myiter, 8, '')
+	else:
+		self.treemodel.set_value(myiter, 8, '%003d' % int(details['runtime']) + _(' min'))
 	#update statusbar
 	self.total += 1
 	self.count_statusbar()
@@ -679,9 +699,7 @@ def clone_movie(self):
 		image_path = os.path.join(self.locations['images'], "default.png")
 	handler = self.Image.set_from_file(image_path)
 
-	#update statusbar
-	self.total = self.total + 1
-	self.count_statusbar()
-	self.populate_treeview()
+	# change_filter calls populate_treeview which updates the status bar
+	quick_filter.change_filter(self)
 
 # vim: fdm=marker
