@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: dbupgrade.py 793 2007-06-30 14:53:26Z piotrek $'
+__revision__ = '$Id: dbupgrade.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2006 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -83,15 +83,33 @@ def upgrade_database(self, version):
 		self.Movie.mapper.mapped_table.create()
 		self.Loan.mapper.mapped_table.create()
 		self.Lang.mapper.mapped_table.create()
-		self.Lang.mapper.mapped_table.insert().execute(name=_('English'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('Brazilian Portuguese'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Bulgarian'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Catalan'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('Czech'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Danish'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Dutch'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('English'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Estonian'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('French'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('German'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Greek'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Hungarian'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Indonesian'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('Italian'))
-		self.Lang.mapper.mapped_table.insert().execute(name=_('Portuguese'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Japanese'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Korean'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Norwegian Bokmal'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Occitan'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Pashto'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('Polish'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Portuguese'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Russian'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Simplified Chinese'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Slovak'))
 		self.Lang.mapper.mapped_table.insert().execute(name=_('Spanish'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Swedish'))
+		self.Lang.mapper.mapped_table.insert().execute(name=_('Turkish'))
 		self.MovieLang.mapper.mapped_table.create()
 		self.Tag.mapper.mapped_table.create()
 		self.Tag.mapper.mapped_table.insert().execute(name=_('Favourite'))
