@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: initialize.py 812 2007-07-25 22:38:27Z piotrek $'
+__revision__ = '$Id: initialize.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ import gutils
 import gobject
 import gettext
 import platform
+import re
 from gettext import gettext as _
 from locale import getdefaultlocale
 
@@ -40,15 +41,18 @@ except:
 
 def locations(self):
 	defaultLang, defaultEnc = getdefaultlocale()
+	if defaultEnc is None:
+		defaultEnc = 'UTF-8'
 	locations = {}
 	locations['exec'] = os.path.abspath(os.path.dirname(sys.argv[0])) # deprecated
 	locations['lib']  = os.path.dirname(__file__)
 	
 	if os.name == 'nt' or os.name == 'win32':
 		import winshell
+		from win32com.shell import shellcon, shell
+		import shutil
+		
 		mydocs = winshell.my_documents()
-		locations['home']           = os.path.join(mydocs, 'griffith').decode(defaultEnc)
-		#locations['home']           = os.path.join(os.path.expanduser('~'), 'griffith')
 		locations['movie_plugins']  = "%s\\lib\\plugins\\movie" % locations['exec']
 		locations['export_plugins'] = "%s\\lib\\plugins\\export" % locations['exec']
 		locations['images']         = "%s\\images" % locations['exec']
@@ -58,6 +62,12 @@ def locations(self):
 		locations['i18n']           = "%s\\i18n" % locations['exec']
 		os.environ['PATH'] += ";lib;"
 		
+		# griffith dir location should point to 'Application Data'
+		# this is changed on 0.9.5+svn so we need to make it backward compatible
+		if os.path.exists(os.path.join(mydocs, 'griffith').decode(defaultEnc)):
+			shutil.move(os.path.join(mydocs, 'griffith').decode(defaultEnc),os.path.join(shell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, 0, 0), 'griffith').decode(defaultEnc))
+		locations['home']           = os.path.join(shell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, 0, 0), 'griffith').decode(defaultEnc)
+		
 		# windows hack for locale setting
 		lang = os.getenv('LANG')
 		if lang is None:
@@ -86,7 +96,7 @@ def locations(self):
 	locations['temp'] = gettempdir()
 	
 	if self._tmp_home is not None: # see gconsole.check_args
-		locations['home'] = self._tmp_home
+		locations['home'] = self._tmp_home.decode(defaultEnc)
 		del self._tmp_home
 
 	try:
@@ -169,7 +179,7 @@ def toolbar(self):
 		self.widgets['menu']['toolbar'].set_active(False)
 
 def treeview(self):
-	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str)
+	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str, str, bool, str, str)
 	self.widgets['treeview'].set_model(self.treemodel)
 	self.widgets['treeview'].set_headers_visible(True)
 	# number column
@@ -177,30 +187,100 @@ def treeview(self):
 	self.number_column=gtk.TreeViewColumn(_('N.'), renderer, text=0)
 	self.number_column.set_resizable(True)
 	self.number_column.set_sort_column_id(0)
+	self.number_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.number_column)
 	# pic column
 	renderer=gtk.CellRendererPixbuf()
 	self.image_column=gtk.TreeViewColumn(_('Image'), renderer, pixbuf=1)
 	self.image_column.set_resizable(False)
+	self.image_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.image_column)
 	# original title column
 	renderer=gtk.CellRendererText()
 	self.otitle_column=gtk.TreeViewColumn(_('Original Title'), renderer, text=2)
 	self.otitle_column.set_resizable(True)
 	self.otitle_column.set_sort_column_id(2)
+	self.otitle_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.otitle_column)
 	# title column
 	renderer=gtk.CellRendererText()
 	self.title_column=gtk.TreeViewColumn(_('Title'), renderer, text=3)
 	self.title_column.set_resizable(True)
 	self.title_column.set_sort_column_id(3)
+	self.title_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.title_column)
 	# director column
 	renderer=gtk.CellRendererText()
 	self.director_column=gtk.TreeViewColumn(_('Director'), renderer, text=4)
 	self.director_column.set_sort_column_id(4)
 	self.director_column.set_resizable(True)
+	self.director_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.director_column)
+	# genre column
+	renderer=gtk.CellRendererText()
+	self.genre_column=gtk.TreeViewColumn(_('Genre'), renderer, text=5)
+	self.genre_column.set_sort_column_id(5)
+	self.genre_column.set_resizable(True)
+	self.genre_column.set_reorderable(True)
+	self.widgets['treeview'].append_column(self.genre_column)
+	# seen column
+	renderer=gtk.CellRendererToggle()
+	self.seen_column=gtk.TreeViewColumn(_('Seen it'), renderer, active=6)
+	self.seen_column.set_sort_column_id(6)
+	self.seen_column.set_resizable(True)
+	self.seen_column.set_reorderable(True)
+	self.widgets['treeview'].insert_column(self.seen_column, 1)
+	# year column
+	renderer=gtk.CellRendererText()
+	renderer.set_property('xalign', 0.5)
+	self.year_column=gtk.TreeViewColumn(_('Year'), renderer, text=7)
+	self.year_column.set_sort_column_id(7)
+	self.year_column.set_resizable(True)
+	self.year_column.set_alignment(0.5)
+	self.year_column.set_reorderable(True)
+	self.widgets['treeview'].append_column(self.year_column)
+	# runtime column
+	renderer=gtk.CellRendererText()
+	renderer.set_property('xalign', 1)
+	self.runtime_column=gtk.TreeViewColumn(_('Runtime'), renderer, text=8)
+	self.runtime_column.set_sort_column_id(8)
+	self.runtime_column.set_resizable(True)
+	self.runtime_column.set_alignment(1)
+	self.runtime_column.set_reorderable(True)
+	self.widgets['treeview'].append_column(self.runtime_column)
+	# reflect saved column order
+	columnorder = self.config.get('columnorder', None, section='mainlist')
+	if not columnorder is None:
+		currentcol = None
+		columnordersplitted = re.split('[ \t]*,[ \t]*', columnorder)
+		for col in columnordersplitted:
+			if col == 'number':
+				self.widgets['treeview'].move_column_after(self.number_column, currentcol)
+				currentcol = self.number_column
+			elif col == 'image':
+				self.widgets['treeview'].move_column_after(self.image_column, currentcol)
+				currentcol = self.image_column
+			elif col == 'otitle':
+				self.widgets['treeview'].move_column_after(self.otitle_column, currentcol)
+				currentcol = self.otitle_column
+			elif col == 'title':
+				self.widgets['treeview'].move_column_after(self.title_column, currentcol)
+				currentcol = self.title_column
+			elif col == 'director':
+				self.widgets['treeview'].move_column_after(self.director_column, currentcol)
+				currentcol = self.director_column
+			elif col == 'genre':
+				self.widgets['treeview'].move_column_after(self.genre_column, currentcol)
+				currentcol = self.genre_column
+			elif col == 'seen':
+				self.widgets['treeview'].move_column_after(self.seen_column, currentcol)
+				currentcol = self.seen_column
+			elif col == 'year':
+				self.widgets['treeview'].move_column_after(self.year_column, currentcol)
+				currentcol = self.year_column
+			elif col == 'runtime':
+				self.widgets['treeview'].move_column_after(self.runtime_column, currentcol)
+				currentcol = self.runtime_column
 	# add data to treeview
 	self.total = int(self.db.Movie.count())
 	self.widgets['treeview'].show()
@@ -464,10 +544,15 @@ def combos(self):
 		self.widgets['add']['layers'].insert_text(i, layer)
 		i += 1
 	i = 0
+	pos_to_activate = 0
+	selected_criteria = self.config.get('criteria', None, section='mainlist')
 	for criteria in self.search_criteria:
-		self.widgets['filter']['criteria'].insert_text(i, self.field_names[criteria])
+		new_criteria = self.field_names[criteria]
+		self.widgets['filter']['criteria'].insert_text(i, new_criteria)
+		if selected_criteria == new_criteria:
+			pos_to_activate = i
 		i += 1
-	self.widgets['filter']['criteria'].set_active(0)
+	self.widgets['filter']['criteria'].set_active(pos_to_activate)
 	i = 0
 	for field in self.sort_criteria:
 		if field != 'movie_id':
@@ -611,6 +696,7 @@ def preferences(self):
 
 def fill_volumes_combo(self, default=0):
 	self.widgets['add']['volume'].get_model().clear()
+	self.widgets['filter']['volume'].get_model().clear()
 	for i in self.volume_combo_ids:
 		vol_id = self.volume_combo_ids[i]
 		if vol_id>0:
@@ -618,7 +704,10 @@ def fill_volumes_combo(self, default=0):
 		else:
 			name = ''
 		self.widgets['add']['volume'].insert_text(int(i), str(name))
+		self.widgets['filter']['volume'].insert_text(int(i), str(name))
 	self.widgets['add']['volume'].show_all()
+	self.widgets['filter']['volume'].show_all()
+	self.widgets['filter']['volume'].set_active(0)
 	i = gutils.findKey(default, self.volume_combo_ids)
 	if i is not None:
 		self.widgets['add']['volume'].set_active(int(i))
