@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: main_treeview.py 774 2007-06-17 20:35:24Z piotrek $'
+__revision__ = '$Id: main_treeview.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -341,7 +341,9 @@ def populate(self, movies=None, where=None):#{{{
 	if movies is None:
 		movies = Select([self.db.Movie.c.number,
 			self.db.Movie.c.o_title, self.db.Movie.c.title,
-			self.db.Movie.c.director, self.db.Movie.c.image])
+			self.db.Movie.c.director, self.db.Movie.c.image,
+			self.db.Movie.c.genre, self.db.Movie.c.seen,
+			self.db.Movie.c.year, self.db.Movie.c.runtime])
 
 	if isinstance(movies, Select):
 		if not where: # because of possible 'seen', 'loaned', 'collection_id' in where
@@ -353,9 +355,17 @@ def populate(self, movies=None, where=None):#{{{
 			if not_seen_only:
 				movies.append_whereclause(self.db.Movie.c.seen==False)
 			# collection
-			col_id = self.collection_combo_ids[self.widgets['filter']['collection'].get_active()]
-			if col_id > 0:
-				movies.append_whereclause(self.db.Movie.c.collection_id==col_id)
+			pos = self.widgets['filter']['collection'].get_active()
+			if pos >= 0:
+				col_id = self.collection_combo_ids[pos]
+				if col_id > 0:
+					movies.append_whereclause(self.db.Movie.c.collection_id==col_id)
+			# volume
+			pos = self.widgets['filter']['volume'].get_active()
+			if pos >= 0:
+				vol_id = self.volume_combo_ids[pos]
+				if vol_id > 0:
+					movies.append_whereclause(self.db.Movie.c.volume_id==vol_id)
 		
 		# select sort column
 		sort_column_name = self.config.get('sortby', 'number', section='mainlist')
@@ -383,7 +393,7 @@ def populate(self, movies=None, where=None):#{{{
 	sort_column_id, order = self.treemodel.get_sort_column_id()
 
 	# new treemodel (faster and prevents some problems)
-	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str)
+	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str, str, bool, str, str)
 
 	# check preferences to hide or show columns
 	if self.config.get('number', True, 'mainlist') == True:
@@ -406,6 +416,22 @@ def populate(self, movies=None, where=None):#{{{
 		self.image_column.set_visible(True)
 	else:
 		self.image_column.set_visible(False)
+	if self.config.get('genre', True, 'mainlist') == True:
+		self.genre_column.set_visible(True)
+	else:
+		self.genre_column.set_visible(False)
+	if self.config.get('seen', True, 'mainlist') == True:
+		self.seen_column.set_visible(True)
+	else:
+		self.seen_column.set_visible(False)
+	if self.config.get('year', True, 'mainlist') == True:
+		self.year_column.set_visible(True)
+	else:
+		self.year_column.set_visible(False)
+	if self.config.get('runtime', True, 'mainlist') == True:
+		self.runtime_column.set_visible(True)
+	else:
+		self.runtime_column.set_visible(False)
 		
 	for movie in movies:
 		myiter = self.treemodel.append(None)
@@ -436,6 +462,11 @@ def populate(self, movies=None, where=None):#{{{
 		self.treemodel.set_value(myiter,2,movie.o_title)
 		self.treemodel.set_value(myiter,3,movie.title)
 		self.treemodel.set_value(myiter,4,movie.director)
+		self.treemodel.set_value(myiter,5,movie.genre)
+		self.treemodel.set_value(myiter,6,movie.seen)
+		self.treemodel.set_value(myiter,7,movie.year)
+		if movie.runtime is not None:
+			self.treemodel.set_value(myiter,8, '%003d' % movie.runtime + _(' min'))
 		
 	# restore user sort column
 	if sort_column_id is not None:
@@ -445,6 +476,7 @@ def populate(self, movies=None, where=None):#{{{
 	self.widgets['treeview'].set_model(self.treemodel)
 	self.widgets['treeview'].thaw_child_notify()
 	self.widgets['treeview'].set_cursor_on_cell(0)
+	self.count_statusbar()
 #}}}
 
 # vim: fdm=marker
