@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: PluginExportHTML.py 828 2007-08-05 19:22:37Z piotrek $'
+__revision__ = '$Id: PluginExportHTML.py 891 2007-12-16 21:13:53Z piotrek $'
 
 # Copyright (c) 2005-2007 Piotr Ożarowski
 #
@@ -41,7 +41,7 @@ plugin_version      = '3.8'
 class ExportPlugin(gtk.Window):
 	#==[ configuration - default values ]==========={{{
 	config = {
-		'sorting'           : 'title',
+		'sorting'           : 'movies_title',
 		'sorting2'          : 'ASC',
 		'exported_dir'      : 'griffith_movies',
 		'template'          : 0,
@@ -60,63 +60,108 @@ class ExportPlugin(gtk.Window):
 		'poster_format'     : 'jpg'
 	}
 	fields = {
-		'cast'         : False,
-		'classification' : False,
-		'country'        : True,
-		'genre'          : True,
-		'director'       : True,
-		'image'          : True,
-		'o_site'         : True,
-		'site'           : True,
-		'trailer'        : True,
-		'loaned'         : False,
-		'medium_id'      : True,
-		'number'         : True,
-		'o_title'        : True,
-		'plot'           : False,
-		'rating'         : True,
-		'runtime'        : True,
-		'studio'         : False,
-		'seen'           : True,
-		'title'          : True,
-		'year'           : True,
-		'notes'          : False,
-#		'region'         : False,
-#		'layers'         : False,
-#		'condition'      : False,
-#		'color'          : False,
-#		'volume_id'      : False,
-#		'collection_id'  : False,
+		'movies_cast'           : False,
+		'movies_classification' : False,
+		'movies_country'        : True,
+		'movies_genre'          : True,
+		'movies_director'       : True,
+		'movies_image'          : True,
+		'movies_o_site'         : True,
+		'movies_site'           : True,
+		'movies_trailer'        : True,
+		'movies_loaned'         : False,
+		'movies_media_num'      : True,
+		'movies_number'         : True,
+		'movies_o_title'        : True,
+		'movies_plot'           : False,
+		'movies_rating'         : True,
+		'movies_runtime'        : True,
+		'movies_studio'         : False,
+		'movies_seen'           : True,
+		'movies_title'          : True,
+		'movies_year'           : True,
+		'movies_notes'          : False,
+#		'movies_region'         : False,
+#		'movies_layers'         : False,
+#		'movies_condition'      : False,
+#		'movies_color'          : False,
+#		'movies_volume_id'      : False,
+#		'movies_collection_id'  : False,
+		'media_name'            : True,
+		'collections_name'      : True,
+		'volumes_name'          : True,
+#		'acodecs_name'          : True,
+		'vcodecs_name'          : True,
+	}
+	
+	fields_as_columns = {
+		'movies_cast'           : 'cast',
+		'movies_classification' : 'classification',
+		'movies_country'        : 'country',
+		'movies_genre'          : 'genre',
+		'movies_director'       : 'director',
+		'movies_image'          : 'image',
+		'movies_o_site'         : 'o_site',
+		'movies_site'           : 'site',
+		'movies_trailer'        : 'trailer',
+		'movies_loaned'         : 'loaned',
+		'movies_media_num'      : 'media_num',
+		'movies_number'         : 'number',
+		'movies_o_title'        : 'o_title',
+		'movies_plot'           : 'plot',
+		'movies_rating'         : 'rating',
+		'movies_runtime'        : 'runtime',
+		'movies_studio'         : 'studio',
+		'movies_seen'           : 'seen',
+		'movies_title'          : 'title',
+		'movies_year'           : 'year',
+		'movies_notes'          : 'notes',
+#		'movies_region'         : 'region',
+#		'movies_layers'         : 'layers',
+#		'movies_condition'      : 'condition',
+#		'movies_color'          : 'color',
+#		'movies_volume_id'      : 'volume_id',
+#		'movies_collection_id'  : 'collection_id',
+		'media_name'            : 'name',
+		'collections_name'      : 'name',
+		'volumes_name'          : 'name',
+#		'acodecs_name'          : 'name',
+		'vcodecs_name'          : 'name',
 	}
 	
 	names = {
-		_('Cast')           : 'cast',
-		_('Classification') : 'classification',
-		_('Country')        : 'country',
-		_('Director')       : 'director',
-		_('Genre')          : 'genre',
-		_('Image')          : 'image',
-		_('Official site')  : 'o_site',
-		_('Site')           : 'site',
-		_('Trailer')        : 'trailer',
-		_('Loaned')         : 'loaned',
-		_('Media')          : 'medium_id',
-		_('Number')         : 'number',
-		_('Original Title') : 'o_title',
-		_('Plot')           : 'plot',
-		_('Rating')         : 'rating',
-		_('Runtime')        : 'runtime',
-		_('Studio')         : 'studio',
-		_('Seen it')        : 'seen',
-		_('Title')          : 'title',
-		_('Year')           : 'year',
-		_('Notes')          : 'notes',
-#		_('Region')         : 'region',
-#		_('Layers')         : 'layers',
-#		_('Condition')      : 'condition',
-#		_('Color')          : 'color',
-#		_('Volume')         : 'volume_id',
-#		_('Collection')     : 'collection_id',
+		_('Cast')           : 'movies_cast',
+		_('Classification') : 'movies_classification',
+		_('Country')        : 'movies_country',
+		_('Director')       : 'movies_director',
+		_('Genre')          : 'movies_genre',
+		_('Image')          : 'movies_image',
+		_('Official site')  : 'movies_o_site',
+		_('Site')           : 'movies_site',
+		_('Trailer')        : 'movies_trailer',
+		_('Loaned')         : 'movies_loaned',
+		_('Discs')          : 'movies_media_num',
+		_('Number')         : 'movies_number',
+		_('Original Title') : 'movies_o_title',
+		_('Plot')           : 'movies_plot',
+		_('Rating')         : 'movies_rating',
+		_('Runtime')        : 'movies_runtime',
+		_('Studio')         : 'movies_studio',
+		_('Seen it')        : 'movies_seen',
+		_('Title')          : 'movies_title',
+		_('Year')           : 'movies_year',
+		_('Notes')          : 'movies_notes',
+#		_('Region')         : 'movies_region',
+#		_('Layers')         : 'movies_layers',
+#		_('Condition')      : 'movies_condition',
+#		_('Color')          : 'movies_color',
+#		_('Volume')         : 'movies_volume_id',
+#		_('Collection')     : 'movies_collection_id',
+		_('Media')          : 'media_name',
+		_('Collection')     : 'collections_name',
+		_('Volume')         : 'volumes_name',
+#		_('Audio codecs')   : 'acodecs_name',
+		_('Video codec')    : 'vcodecs_name',
 	}
 	#}}}
 
@@ -124,6 +169,10 @@ class ExportPlugin(gtk.Window):
 		self.db = database
 		self.debug = debug
 		self.locations = locations
+		if kwargs.has_key('config'):
+			self.persistent_config = kwargs['config']
+		else:
+			self.persistent_config = None
 		self.widgets = {}
 		self.style_list = {}
 		self.templates = self.make_template_list()
@@ -243,6 +292,7 @@ class ExportPlugin(gtk.Window):
 			'sb_width'              : get('sb_width'),
 			'cb_black'              : get('cb_black'),
 			'combo_format'          : get('combo_format'),
+			'cb_convert'            : get('cb_convert'),
 		}
 
 		# define handlers for general events
@@ -271,14 +321,21 @@ class ExportPlugin(gtk.Window):
 			self.widgets['combo_theme'].insert_text(i, self.templates[i]['name'])
 
 		# sortby combo
-		for i in self.names:
+		keys = self.names.keys()
+		keys.sort()
+		j = 0
+		pos_o_title = 0
+		for i in keys:
 			self.widgets['combo_sortby'].append_text(i)
+			if i == _('Original Title'):
+				pos_o_title = j
+			j = j + 1
 		self.widgets['combo_sortby'].set_wrap_width(3)
 
 		# include data
 		j = 0
 		k = math.ceil( len(self.names) / float(3) )
-		for i in self.names:
+		for i in keys:
 			j = j + 1
 			field = self.names[i]
 			self.widgets['cb_'+field] = gtk.CheckButton(i)
@@ -298,7 +355,7 @@ class ExportPlugin(gtk.Window):
 		# set defaults --------------------------------
 		self.widgets['entry_header'].set_text(self.config['title'])
 		self.widgets['combo_theme'].set_active(2)	# html_tables
-		self.widgets['combo_sortby'].set_active(17)	# orginal title
+		self.widgets['combo_sortby'].set_active(pos_o_title)	# orginal title
 		# spliting
 		self.widgets['sb_split_num'].set_value(self.config['split_num'])
 		if self.config['split_by'] == 0:
@@ -320,10 +377,17 @@ class ExportPlugin(gtk.Window):
 			self.widgets['rb_loaned'].set_active(True)
 		# posters
 		self.widgets['combo_format'].set_active(0)
-		if self.config['poster_convert']:
+		if self.config['poster_convert'] and self.config['poster_convert'] == True:
+			self.widgets['cb_convert'].set_active(True)
 			self.widgets['vb_posters'].set_sensitive(True)
 		else:
+			self.widgets['cb_convert'].set_active(False)
 			self.widgets['vb_posters'].set_sensitive(False)
+		# persistent config
+		if not self.persistent_config is None:
+			tmp = self.persistent_config.get('export_dir', None, section='export-html')
+			if not tmp is None:
+				self.widgets['fcw'].set_current_folder(tmp)
 	#}}}
 
 	#==[ callbacks ]================================{{{
@@ -483,19 +547,55 @@ class ExportPlugin(gtk.Window):
 		
 		# columns to select
 		columns = []
-		for i in self.fields:
-			columns.append(self.db.Movie.c[i])
+		for i in self.fields_as_columns:
+			try:
+				columns.append(self.db.Movie.c[self.fields_as_columns[i]])
+			except:
+				pass
+		# use outer join to media table to get the name of the media
+		from sqlalchemy import outerjoin
+		columns.append(self.db.Medium.c['name'])
+		media_join = outerjoin(self.db.metadata.tables['movies'], \
+			self.db.metadata.tables['media'], \
+			self.db.metadata.tables['movies'].c.medium_id==self.db.metadata.tables['media'].c.medium_id)
+		# use outer join to collections table to get the name of the collection
+		columns.append(self.db.Collection.c['name'])
+		collection_join = media_join.outerjoin( \
+			self.db.metadata.tables['collections'], \
+			self.db.metadata.tables['movies'].c.collection_id==self.db.metadata.tables['collections'].c.collection_id)
+		# use outer join to volumes table to get the name of the volume
+		columns.append(self.db.Volume.c['name'])
+		volume_join = collection_join.outerjoin( \
+			self.db.metadata.tables['volumes'], \
+			self.db.metadata.tables['movies'].c.volume_id==self.db.metadata.tables['volumes'].c.volume_id)
+		# use outer join to volumes table to get the name of the volume
+		columns.append(self.db.VCodec.c['name'])
+		vcodec_join = volume_join.outerjoin( \
+			self.db.metadata.tables['vcodecs'], \
+			self.db.metadata.tables['movies'].c.vcodec_id==self.db.metadata.tables['vcodecs'].c.vcodec_id)
+		#
+		# selecting the audio codec doesn't work with joins because if more than one codec per movie is
+		# added it would duplicate the movie in the result set as many as audio codecs are added to the movie
+		#
+		# use outer join to language and acodec table to get the name of the audio codec
+		#movie_lang_join = vcodec_join.outerjoin( \
+		#	self.db.metadata.tables['movie_lang'], \
+		#	self.db.metadata.tables['movies'].c.movie_id==self.db.metadata.tables['movie_lang'].c.movie_id)
+		#columns.append(self.db.ACodec.c['name'])
+		#acodec_join = movie_lang_join.outerjoin( \
+		#	self.db.metadata.tables['acodec'], \
+		#	self.db.metadata.tables['movie_lang'].c.acodec_id==self.db.metadata.tables['acodec'].c.acodec_id)
 		
 		# sort order	TODO: more than one sort column
 		sort_columns = []
 		if config['sorting2'] == 'ASC':
 			from sqlalchemy import asc
-			sort_columns.append(asc(self.db.Movie.c[config['sorting']]))
+			sort_columns.append(asc(self.db.Movie.c[self.fields_as_columns[config['sorting']]]))
 		elif config['sorting2'] == 'DESC':
 			from sqlalchemy import desc
-			sort_columns.append(desc(self.db.Movie.c[config['sorting']]))
+			sort_columns.append(desc(self.db.Movie.c[self.fields_as_columns[config['sorting']]]))
 
-		statement = select(columns=columns, order_by=sort_columns)
+		statement = select(columns=columns, order_by=sort_columns, from_obj=[media_join, collection_join, volume_join, vcodec_join], use_labels = True)
 
 		# where clause
 		if config['seen_only'] == 1:
@@ -553,20 +653,25 @@ class ExportPlugin(gtk.Window):
 				gutils.copytree(data_path, config['exported_dir'])
 			except Exception, err:
 				gutils.warning(self, str(err))
+		
+		# persist config
+		if not self.persistent_config is None:
+			self.persistent_config.set('export_dir', config['exported_dir'], section='export-html')
+			self.persistent_config.save()
 
-		if fields['image']:
+		if fields['movies_image']:
 			# import modules needed later
-			if config['poster_convert']:
-				from PIL import Image
-				# py2exe problem workaround:
-				# if self.windows:
-				from PIL import PngImagePlugin
-				from PIL import GifImagePlugin
-				from PIL import JpegImagePlugin
-				Image._initialized=2
-				# end if
-			else:
-				config['poster_format'] = 'jpg' # replace 'jpeg'
+			# modules are needed at least to convert griffith.png to nopic.(gif|jpeg|png)
+			from PIL import Image
+			# py2exe problem workaround:
+			# if self.windows:
+			from PIL import PngImagePlugin
+			from PIL import GifImagePlugin
+			from PIL import JpegImagePlugin
+			Image._initialized=2
+			# end if
+			if not config['poster_convert']:
+				config['poster_format'] = 'jpeg' # replace 'jpeg'
 			
 			posters_dir = os.path.join(config['exported_dir'], 'posters')
 			if os.path.isdir(posters_dir):
@@ -684,12 +789,13 @@ class ExportPlugin(gtk.Window):
 			tmp = self.fill_template(tmp, 'item', str(i))
 			for j in self.names:
 				if self.fields[self.names[j]] == True:
-					if self.names[j] == 'image':
-						if row['image']:
-							image = row['image'] + '.' + config['poster_format'].lower()
+					if self.names[j] == 'movies_image':
+						if row['movies_image']:
+							#image = row['movies_image'] + '.' + config['poster_format'].lower()
+							image = '%d' % row['movies_number'] + '.' + config['poster_format'].lower()
 							tmp = self.fill_template(tmp, self.names[j], image, j)
 						else:
-							tmp = self.fill_template(tmp, self.names[j], '', j)
+							tmp = self.fill_template(tmp, self.names[j], 'nopic.' + config['poster_format'].lower(), j)
 					elif row[self.names[j]] is None:
 						tmp = self.fill_template(tmp, self.names[j], '', j)
 					elif row[self.names[j]] is True:
@@ -700,10 +806,10 @@ class ExportPlugin(gtk.Window):
 						try:
 							tmp = self.fill_template(tmp, self.names[j], str(row[self.names[j]]).encode('utf-8'), j)
 						except UnicodeDecodeError:
-							self.debug.show("Unicode Decode Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['number']))
+							self.debug.show("Unicode Decode Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
 							tmp = self.fill_template(tmp, self.names[j], str(row[self.names[j]]), j)
 						except Exception, ex:
-							self.debug.show("Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['number']))
+							self.debug.show("Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
 				else:
 					tmp = self.fill_template(tmp, self.names[j], remove=True)
 				tmp = gutils.convert_entities(tmp)
@@ -712,21 +818,22 @@ class ExportPlugin(gtk.Window):
 			# ---------------------------------------------
 			
 			# copy poster
-			if fields['image']:
-				if row['image'] is not None:
-					image_file = os.path.join(self.locations['posters'], str(row['image']) + '.jpg')
+			if fields['movies_image']:
+				if row['movies_image'] is not None:
+					image_file_src = os.path.join(self.locations['posters'], str(row['movies_image']) + '.jpg')
+					image_file_dst = os.path.join(posters_dir, '%d' % row['movies_number']) + '.' + config['poster_format'].lower()
 					if not config['poster_convert']:	# copy file
 						try:
-							shutil.copy(image_file,	posters_dir)
+							shutil.copy(image_file_src,	image_file_dst)
 						except:
-							self.debug.show("Can't copy %s" % image_file)
+							self.debug.show("Can't copy %s" % image_file_src)
 					else:	# convert posters
 						try:
-							im = Image.open(image_file, 'r').convert(config['poster_mode'])
+							im = Image.open(image_file_src, 'r').convert(config['poster_mode'])
 							im.thumbnail((config['poster_width'], config['poster_height']), Image.ANTIALIAS)
-							im.save(os.path.join(posters_dir, row['image']) + '.' + config['poster_format'].lower(), config['poster_format'])
+							im.save(image_file_dst, config['poster_format'])
 						except:
-							self.debug.show("Can't convert %s" % image_file)
+							self.debug.show("Can't convert %s" % image_file_src)
 
 			# close file if last item
 			if ((page-1)*self.entries_per_page)+item == number_of_exported_movies:
@@ -747,6 +854,18 @@ class ExportPlugin(gtk.Window):
 				item=item+1
 			i=i+1
 		#}}}
+		# convert/copy the griffith picture for movies without a poster
+		image_file_src = os.path.join(self.locations['images'], 'griffith.png')
+		image_file_dst = os.path.join(posters_dir, 'nopic.' + config['poster_format'].lower())
+		try:
+			if config['poster_convert']:
+				im = Image.open(image_file_src, 'r').convert(config['poster_mode'])
+				im.thumbnail((config['poster_width'], config['poster_height']), Image.ANTIALIAS)
+			else:
+				im = Image.open(image_file_src, 'r')
+			im.save(image_file_dst, config['poster_format'])
+		except:
+			self.debug.show("Can't convert %s" % image_file_src)
 		gutils.info(self, _("Document has been generated."), self)
 		self.on_quit()
 	#}}}
