@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportPDF.py 773 2007-06-17 19:41:19Z piotrek $'
+__revision__ = '$Id: PluginExportPDF.py 894 2008-01-06 20:24:35Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -28,6 +28,7 @@ from reportlab.lib.units import mm, inch
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.ttfonts import TTFont
 from reportlab.rl_config import defaultPageSize
+from reportlab.rl_config import defaultEncoding
 from reportlab.platypus import Image, SimpleDocTemplate, Paragraph, Spacer
 from reportlab.lib.styles import getSampleStyleSheet
 from xml.sax import saxutils
@@ -37,6 +38,8 @@ import gutils
 import string
 import sys
 import config
+from locale import getdefaultlocale
+from sqlalchemy import Select
 
 exec_location = os.path.abspath(os.path.dirname(sys.argv[0]))
 
@@ -51,7 +54,7 @@ class ExportPlugin:
         self.db = database
         self.locations = locations
         self.parent = parent_window
-	self.config = kwargs['config']
+        self.config = kwargs['config']
         self.styles = getSampleStyleSheet()
         self.export_simple_pdf()
         self.fontName = ""
@@ -65,10 +68,20 @@ class ExportPlugin:
         else:
                 self.fontName = "Helvetica"
 
-        filename = gutils.file_chooser(_("Export a PDF"), action=gtk.FILE_CHOOSER_ACTION_SAVE, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name="griffith_simple_list.pdf")
+        basedir = None
+        if not self.config is None:
+            basedir = self.config.get('export_dir', None, section='export-pdf')
+        if basedir is None:
+            filename = gutils.file_chooser(_("Export a PDF"), action=gtk.FILE_CHOOSER_ACTION_SAVE, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name="griffith_simple_list.pdf")
+        else:
+            filename = gutils.file_chooser(_("Export a PDF"), action=gtk.FILE_CHOOSER_ACTION_SAVE, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name="griffith_simple_list.pdf",folder=basedir)
         if filename[0]:
+            if not self.config is None and filename[1]:
+                self.config.set('export_dir', filename[1], section='export-pdf')
+                self.config.save()
             overwrite = None
-            if os.path.isfile(filename[0]):
+            pdffilename = filename[0].decode('utf-8')
+            if os.path.isfile(pdffilename):
                 response = gutils.question(self,_("File exists. Do you want to overwrite it?"),1,self.parent)
                 if response==-8:
                     overwrite = True
@@ -76,7 +89,16 @@ class ExportPlugin:
                     overwrite = False
                     
             if overwrite == True or overwrite is None:
-                c = SimpleDocTemplate(filename[0])
+                # filename encoding
+                defaultLang, defaultEnc = getdefaultlocale()
+                if defaultEnc is None:
+                    defaultEnc = 'UTF-8'
+                c = SimpleDocTemplate(pdffilename.encode(defaultEnc))
+                # data encoding
+                if defaultEncoding == 'WinAnsiEncoding':
+                    defaultEnc = 'cp1252'
+                else:
+                    defaultEnc = 'utf-8'
                 style = self.styles["Normal"]
                 Story = [Spacer(1,2*inch)]
                 # define some custom stylesheetfont
@@ -87,27 +109,38 @@ class ExportPlugin:
                 p = Paragraph("<font name='" + self.fontName +"' size=\"10\">" + saxutils.escape((_("Total Movies: %s") % str(total)).encode('utf-8'))  + '</font>', self.styles["Heading3"])
                 Story.append(p)
                 Story.append(Paragraph(" ",style))
-                movies = self.db.Movie.select()
-		for movie in movies:
+                movies = Select(self.db.Movie.c)
+                # select sort column
+                sort_column_name = self.config.get('sortby', 'number', section='mainlist')
+                sort_reverse = self.config.get('sortby_reverse', False, section='mainlist')
+                for i in sort_column_name.split(','):
+                    if self.db.Movie.c.has_key(i):
+                        if sort_reverse:
+                            movies.order_by_clause.append(desc(self.db.Movie.c[i]))
+                        else:
+                            movies.order_by_clause.append(self.db.Movie.c[i])
+                movies = movies.execute().fetchall()
+                for movie in movies:
                     number = movie.number
-                    original_title = str(movie.o_title)
-                    title = str(movie.title)
+                    original_title = str(movie.o_title).encode(defaultEnc)
+                    title = str(movie.title).encode(defaultEnc)
                     if movie.year:
                         year = ' - ' + str(movie.year)
                     else:
                         year = ""
                     if movie.director:
-                        director = ' - ' + str(movie.director)
+                        director = ' - ' + str(movie.director).encode(defaultEnc)
                     else:
                         director = ""
-                    p = Paragraph("<font name=" + self.fontName + " size=\"7\">" + \
-                        saxutils.escape(str(number) + " | " + original_title) + \
-                        "</font><font name=" + self.fontName + " size=\"7\">" + \
-                        saxutils.escape(" (" + title + ")" + year + director) + \
-                        "</font>", self.styles["Normal"])
+                    paragraph_text = '<font name=' + self.fontName + ' size="7">' + \
+                        saxutils.escape(str(number) + ' | ' + original_title) + \
+                        '</font><font name=' + self.fontName + ' size="7">' + \
+                        saxutils.escape(' (' + title + ')' + year + director) + \
+                        '</font>'
+                    p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Normal'])
                     Story.append(p)
                 c.build(Story, onFirstPage=self.page_template, onLaterPages=self.page_template)
-                gutils.info(self, _("PDF has been created."), self.parent)
+                gutils.info(self, _('PDF has been created.'), self.parent)
             
     def page_template(self, canvas, doc):
         canvas.saveState()
