@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__revision__ = '$Id: PluginMovieAniDB.py 709 2007-01-15 19:57:20Z piotrek $'
+__revision__ = '$Id: PluginMovieAniDB.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Piotr Ożarowski
+# Copyright (c) 2005-2008 Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,11 +28,11 @@ from gutils import decompress
 
 plugin_name         = 'AnimeDB'
 plugin_description  = 'Anime DataBase'
-plugin_url          = 'www.anidb.info'
+plugin_url          = 'www.anidb.net'
 plugin_language     = _('English')
 plugin_author       = 'Piotr Ożarowski'
 plugin_author_email = '<ozarow+griffith@gmail.com>'
-plugin_version      = '2.4'
+plugin_version      = '2.5'
 
 aid_pattern = re.compile('[?&;]aid=(\d+)')
 
@@ -44,7 +44,7 @@ class Plugin(movie.Movie):
 			self.movie_id = 'anidb'
 		else:
 			self.movie_id = str(id)
-			self.url = "http://anidb.info/perl-bin/animedb.pl?show=anime&aid=%s" % self.movie_id
+			self.url = "http://anidb.net/perl-bin/animedb.pl?show=anime&aid=%s" % self.movie_id
 
 	def initialize(self):
 		self.page = decompress(self.page)
@@ -52,7 +52,7 @@ class Plugin(movie.Movie):
 			aid =  aid_pattern.search(self.page)
 			if aid:
 				self.movie_id = aid.groups()[0]
-				self.url = "http://anidb.info/perl-bin/animedb.pl?show=anime&aid=%s" % self.movie_id
+				self.url = "http://anidb.net/perl-bin/animedb.pl?show=anime&aid=%s" % self.movie_id
 			else:
 				return False
 		self.page = gutils.after(self.page, 'id="layout-content"')
@@ -61,38 +61,38 @@ class Plugin(movie.Movie):
 			self.page = self.page[:pos]
 
 	def get_image(self):
-		match = re.search('http://img\d*.anidb.info/pics/anime/\d*.jpg', self.page)
+		match = re.search('http://img\d*.anidb.net/pics/anime/\d*.jpg', self.page)
 		if match is not None:
 			self.image_url = match.group()
 		else:
 			self.image_url = ''
 
 	def get_o_title(self):
-		self.o_title = gutils.trim(self.page, '"field">Title', '</td>')
-		self.o_title = gutils.after(self.o_title, '"value">')
-		self.o_title = re.sub(' \(\d*\)', '', self.o_title)
+		self.o_title = gutils.trim(self.page, '<h1>Anime: ', '</h1>')
 
 	def get_title(self):
-		self.title = gutils.trim(self.page,'"field">English', '</td>')
+		self.title = gutils.trim(self.page, '"field">Official Title', '</td>')
+		self.title = gutils.trim(self.title, '<span>', '</span>')
 
 	def get_director(self):
 		self.director = ''
 
 	def get_plot(self):
-		self.plot = gutils.trim(self.page, 'class="desc">', '</p>')
+		self.plot = gutils.trim(self.page, 'class="desc">', '</div>')
 
 	def get_year(self):
 		self.year = gutils.trim(self.page, '"field">Year', '</td>')
-		self.year = gutils.after(self.year, '"value">')[:4]
+		self.year = gutils.after(self.year, '"value">')[-4:]
 
 	def get_runtime(self):
 		self.runtime = ''
 
 	def get_genre(self):
-		self.genre = gutils.trim(self.page, '"field">Genre', '</td>')
+		self.genre = gutils.trim(self.page, '>Categories<', '</td>')
+		self.genre = gutils.after(self.genre, 'value">')
 		self.genre = gutils.strip_tags(self.genre)
-		if len(self.genre) and self.genre.endswith('[similar]'):
-			self.genre =  self.genre[:-11]
+		if len(self.genre) and self.genre.endswith('- similar'):
+			self.genre =  self.genre[:-9]
 		elif self.genre == '-':
 			self.genre = ''
 		self.genre = string.replace(self.genre, '\n', '')
@@ -144,8 +144,8 @@ class Plugin(movie.Movie):
 class SearchPlugin(movie.SearchMovie):
 	def __init__(self):
 		self.encode = 'utf-8'
-		self.original_url_search	= 'http://anidb.info/perl-bin/animedb.pl?show=animelist&do.search=search&adb.search='
-		self.translated_url_search	= 'http://anidb.info/perl-bin/animedb.pl?show=animelist&do.search=search&adb.search='
+		self.original_url_search	= 'http://anidb.net/perl-bin/animedb.pl?show=animelist&do.search=search&adb.search='
+		self.translated_url_search	= 'http://anidb.net/perl-bin/animedb.pl?show=animelist&do.search=search&adb.search='
 
 	def search(self,parent_window):
 		self.open_search(parent_window)
