@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieKinoDe.py 806 2007-07-04 21:23:47Z mikej06 $'
+__revision__ = '$Id: PluginMovieKinoDe.py 891 2007-12-16 21:13:53Z piotrek $'
 
 # Copyright (c) 2006-2007
 #
@@ -33,7 +33,7 @@ plugin_url = "www.kino.de"
 plugin_language = _("German")
 plugin_author = "Michael Jahn"
 plugin_author_email = "<mikej06@hotmail.com>"
-plugin_version = "1.9"
+plugin_version = "1.11"
 
 class Plugin(movie.Movie):
 	url_to_use = "http://www.kino.de/kinofilm/"
@@ -74,18 +74,18 @@ class Plugin(movie.Movie):
 				self.image_url = 'http://images.kino.de/flbilder' + tmpdata + '.jpg'
 
 	def get_o_title(self):
-		self.o_title = gutils.trim(self.tmp_page,"span class=\"standardsmall\"><br />(",")<")
-		if self.o_title == "":
-			if self.url_type == "V":
-				self.o_title = gutils.after(gutils.trim(self.tmp_page,"\"headline2\"><a href=\"/videofilm", "</a>"), ">")
+		self.o_title = gutils.trim(self.tmp_page, 'span class="standardsmall">(', ')<')
+		if self.o_title == '':
+			if self.url_type == 'V':
+				self.o_title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/videofilm', '</a>'), '>')
 			else:
-				self.o_title = gutils.after(gutils.trim(self.tmp_page,"\"headline2\"><a href=\"/kinofilm", "</a>"), ">")
+				self.o_title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/kinofilm', '</a>'), '>')
 
 	def get_title(self):
 		if self.url_type == "V":
-			self.title = gutils.after(gutils.trim(self.tmp_page,"\"headline2\"><a href=\"/videofilm", "</a>"), ">")
+			self.title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/videofilm', '</a>'), '>')
 		else:
-			self.title = gutils.after(gutils.trim(self.tmp_page,"\"headline2\"><a href=\"/kinofilm", "</a>"), ">")
+			self.title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/kinofilm', '</a>'), '>')
 
 	def get_director(self):
 		self.director = gutils.trim(self.tmp_creditspage,"Regie","</a>")
@@ -94,36 +94,43 @@ class Plugin(movie.Movie):
 
 	def get_plot(self):
 		# little steps to perfect plot (I hope ... it's a terrible structured content ... )
-		self.plot = gutils.trim(self.tmp_page, '<span style="line-height:', '</spa')
-		if self.plot == '':
-			self.plot = gutils.trim(self.tmp_page,"Kurzinfo", "</td></tr><tr><td></td>")
-			if (self.plot == ''):
-				self.plot = gutils.trim(self.tmp_page,"Kurzinfo", '<script ')
-				self.plot = gutils.after(self.plot, '>')
-			while len(self.plot) and string.find(self.plot, '</A>') > -1:
-				self.plot = gutils.after(self.plot, '</A>');
-			self.plot = gutils.after(gutils.after(self.plot, '</table>'), '>')
+		self.plot = gutils.before(self.tmp_page, '<!-- PRINT-CONTENT-ENDE-->')
+		self.plot = self.regextrim(self.plot, 'Kurzinfo', '</td></tr>[ \t\r\n]*<tr><td></td></tr>')
+		if self.plot != '':
+			lastpos = self.plot.rfind('</table>')
+			if lastpos == -1:
+				self.plot = ''
+			else:
+				self.plot = self.plot[lastpos:]
 		else:
-			self.plot = gutils.after(self.plot, '>')
+			self.plot = gutils.trim(self.tmp_page, '<span style="line-height:', '</spa')
+			if self.plot == '':
+				self.plot = gutils.trim(self.tmp_page,"Kurzinfo", "</td></tr><tr><td></td>")
+				if (self.plot == ''):
+					self.plot = gutils.trim(self.tmp_page,"Kurzinfo", '<script ')
+					self.plot = gutils.after(self.plot, '>')
+				while len(self.plot) and string.find(self.plot, '</A>') > -1:
+					self.plot = gutils.after(self.plot, '</A>');
+				self.plot = gutils.after(gutils.after(self.plot, '</table>'), '>')
+			else:
+				self.plot = gutils.after(self.plot, '>')
 
 	def get_year(self):
-		self.year = self.regextrim(self.tmp_page,"class=\"standardsmall\"><br /><b>(DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</b> - <b>","<br />")
-		if self.year == "":
-			self.year = gutils.trim(self.tmp_page,"class=\"standardsmall\"><b>","<br />")
-		self.year = gutils.trim(self.year,"<b>","</b>")
-		self.year = gutils.after(self.year," ")
+		self.year = ''
+		tmp = self.regextrim(self.tmp_page, 'span class="standardsmall"[^>]*><strong>', '</span>')
+		if tmp <> None:
+			srchresult = re.search('[0-9][0-9][0-9][0-9]</strong>', tmp)
+			if srchresult <> None:
+				self.year = srchresult.string[srchresult.start():srchresult.end()]
 
 	def get_runtime(self):
-		self.runtime = gutils.trim(self.tmp_page,"Jahren</b> - <b>"," Min.")
-		if (self.runtime == ''):
-			self.runtime = gutils.trim(self.tmp_page,"Jahren</b></b> - <b>"," Min.")
-		if (self.runtime == ''):
-			self.runtime = gutils.trim(self.tmp_page,"</b><br /><b>"," Min.")
+		self.runtime = ''
+		srchresult = re.search('>[0-9]+[ \t]Min[.]<', self.tmp_page)
+		if srchresult <> None:
+			self.runtime = self.regextrim(srchresult.string[srchresult.start():srchresult.end()], '>', '[^0-9]')
 
 	def get_genre(self):
-		self.genre = self.regextrim(self.tmp_page,"class=\"standardsmall\"><br /><b>(DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</b> - <b>","</b>")
-		if self.genre == "":
-			self.genre = gutils.trim(self.tmp_page,"class=\"standardsmall\"><b>","</b>")
+		self.genre = self.regextrim(self.tmp_page,'span class="standardsmall"[^>]*>[ \t\r\n]*<strong>((DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</strong>[ \t]-[ \t]<strong>)*', '</strong>[ \t]-[ \t]<strong>')
 
 	def get_cast(self):
 		self.cast = gutils.trim(self.tmp_creditspage,'>Cast<', '</table><br')
@@ -148,12 +155,12 @@ class Plugin(movie.Movie):
 			self.cast = string.replace(self.cast, "--flip--", _(" as "))
 
 	def get_classification(self):
-		self.classification = gutils.trim(self.tmp_page,"FSK: ","</b>")
+		self.classification = self.regextrim(self.tmp_page,'FSK:( |&nbsp;)+', '</strong>')
 
 	def get_studio(self):
-		self.studio = gutils.trim(self.tmp_page,"Verleih: ", "</b>")
+		self.studio = self.regextrim(self.tmp_page, 'Verleih:( |&nbsp;)+', '( - |&nbsp;-&nbsp;)*</strong>')
 		if (self.studio == ""):
-			self.studio = gutils.trim(self.tmp_page,"Anbieter: ", "</b>")
+			self.studio = self.regextrim(self.tmp_page, 'Anbieter:( |&nbsp;)+', '( - |&nbsp;-&nbsp;)*</strong>')
 
 	def get_o_site(self):
 		self.o_site = ""
@@ -165,11 +172,12 @@ class Plugin(movie.Movie):
 		self.trailer = ""
 
 	def get_country(self):
-		self.country = self.regextrim(self.tmp_page,"class=\"standardsmall\"><br /><b>(DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</b> - <b>","<br />")
-		if self.country == "":
-			self.country = gutils.trim(self.tmp_page,"class=\"standardsmall\"><b>","<br />")
-		self.country = gutils.trim(self.country,"<b>","</b>")
-		self.country = gutils.before(self.country," ")
+		self.country = self.regextrim(self.tmp_page, 'span class="standardsmall"[^>]*><strong>((DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</strong>[ \t]-[ \t]<strong>)*', '</span>')
+		if self.country <> None:
+			self.country = self.regextrim(self.country, '-[ \t]<strong>', '</strong>')
+			self.country = re.sub('[0-9]+$', '', self.country)
+		else:
+			self.country = ''
 
 	def get_rating(self):
 		self.rating = "0"
@@ -199,7 +207,7 @@ class Plugin(movie.Movie):
 		if obj is None:
 			return ''
 		else:
-			p2 = p1 + obj.end()
+			p2 = p1 + obj.start()
 		return text[p1:p2]
 
 #
@@ -259,7 +267,7 @@ class SearchPlugin(movie.SearchMovie):
 		return self.page
 
 	def get_searches(self):
-		elements1 = re.split('headline3"><a href="(http://www.kino.de)*/kinofilm/', self.page)
+		elements1 = re.split('headline3"[^>]*>[ \t\r\n]*<a href="(http://www.kino.de)*/kinofilm/', self.page)
 		elements1[0] = None
 		for element in elements1:
 			if element <> None:
@@ -275,7 +283,7 @@ class SearchPlugin(movie.SearchMovie):
 					'( - (', '('), '))', ')')
 				)
 
-		elements2 = re.split('headline3"><a href="(http://www.kino.de)*/videofilm/', self.page)
+		elements2 = re.split('headline3"[^>]*>[ \t\r\n]*<a href="(http://www.kino.de)*/videofilm/', self.page)
 		elements2[0] = None
 		for element in elements2:
 			if element <> None:
@@ -290,3 +298,135 @@ class SearchPlugin(movie.SearchMovie):
 					),
 					'( - (', '('), '))', ')')
 				)
+
+#
+# Plugin Test
+#
+class SearchPluginTest(SearchPlugin):
+	#
+	# Configuration for automated tests:
+	# dict { movie_id -> expected result count }
+	#
+	test_configuration = {
+		'Rocky Balboa'			: 6,
+		'Arahan'				: 5,
+		'Ein glückliches Jahr'	: 3
+	}
+
+class PluginTest:
+	#
+	# Configuration for automated tests:
+	# dict { movie_id -> dict { arribute -> value } }
+	#
+	# value: * True/False if attribute only should be tested for any value
+	#        * or the expected value
+	#
+	test_configuration = {
+		'K_rocky-balboa/96132.html' : { 
+			'title' 			: 'Rocky Balboa',
+			'o_title' 			: 'Rocky Balboa',
+			'director'			: 'Sylvester Stallone',
+			'plot' 				: True,
+			'cast'				: 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
+Antonio Traver' + _(' as ') + 'Mason "The Line" Dixon\n\
+Burt Young' + _(' as ') + 'Paulie\n\
+Geraldine Hughes' + _(' as ') + 'Marie\n\
+Milo Ventimiglia' + _(' as ') + 'Rocky Jr.\n\
+James Francis Kelly III' + _(' as ') + 'Steps\n\
+Tony Burton' + _(' as ') + 'Duke\n\
+A.J. Benza' + _(' as ') + 'L.C.',
+			'country'			: 'USA',
+			'genre'				: 'Drama',
+			'classification'	: 'Freigegeben ab 12 Jahren',
+			'studio'			: 'Fox',
+			'o_site'			: False,
+			'site'				: 'http://www.kino.de/kinofilm/rocky-balboa/96132.html',
+			'trailer'			: False,
+			'year'				: 2006,
+			'notes'				: False,
+			'runtime'			: 102,
+			'image'				: True,
+			'rating'			: False
+		},
+		'K_ein-glueckliches-jahr/28675.html' : { 
+			'title' 			: 'Ein glückliches Jahr',
+			'o_title' 			: 'La bonne année',
+			'director'			: 'Claude Lelouch',
+			'plot' 				: True,
+			'cast'				: 'Lino Ventura\n\
+Françoise Fabian\n\
+Charles Gérard\n\
+André Falcon',
+			'country'			: 'Frankreich/Italien',
+			'genre'				: 'Drama',
+			'classification'	: 'Freigegeben ab 12 Jahren',
+			'studio'			: 'Columbia TriStar',
+			'o_site'			: False,
+			'site'				: 'http://www.kino.de/kinofilm/ein-glueckliches-jahr/28675.html',
+			'trailer'			: False,
+			'year'				: 1973,
+			'notes'				: False,
+			'runtime'			: 115,
+			'image'				: False,
+			'rating'			: False
+		},
+		'V_ein-glueckliches-jahr-dvd/85546.html' : { 
+			'title' 			: 'Ein glückliches Jahr',
+			'o_title' 			: 'La bonne année',
+			'director'			: 'Claude Lelouch',
+			'plot' 				: True,
+			'cast'				: 'Lino Ventura\n\
+Françoise Fabian\n\
+Charles Gérard\n\
+André Falcon',
+			'country'			: 'Frankreich/Italien',
+			'genre'				: 'Drama',
+			'classification'	: 'Freigegeben ab 12 Jahren',
+			'studio'			: 'Black Hill Pictures',
+			'o_site'			: False,
+			'site'				: 'http://www.kino.de/videofilm/ein-glueckliches-jahr-dvd/85546.html',
+			'trailer'			: False,
+			'year'				: 1973,
+			'notes'				: 'Sprachen:\n\
+Deutsch DD 2.0, Französisch DD 2.0\n\
+\n\
+Mehrkanalton:\n\
+Dolby Digital 2.0\n\
+\n\
+EAN:\n\
+7321921998843',
+			'runtime'			: 110,
+			'image'				: True,
+			'rating'			: False
+		},
+		'V_arahan-vanilla-dvd/90405.html' : { 
+			'title' 			: 'Arahan (Vanilla-DVD)',
+			'o_title' 			: 'Arahan jangpung dae jakjeon',
+			'director'			: 'Ryoo Seung-wan',
+			'plot' 				: True,
+			'cast'				: 'Ryu Seung-beom' + _(' as ') + 'Sang-hwan\n\
+Yoon So-yi' + _(' as ') + 'Wi-jin\n\
+Ahn Sung-kee' + _(' as ') + 'Ja-woon\n\
+Jung Doo-hong' + _(' as ') + 'Heuk-woon\n\
+Yun Ju-sang' + _(' as ') + 'Mu-woon',
+			'country'			: 'Südkorea',
+			'genre'				: 'Action/Komödie',
+			'classification'	: 'Freigegeben ab 16 Jahren',
+			'studio'			: 'Splendid',
+			'o_site'			: False,
+			'site'				: 'http://www.kino.de/videofilm/arahan-vanilla-dvd/90405.html',
+			'trailer'			: False,
+			'year'				: 2004,
+			'notes'				: 'Sprachen:\n\
+Deutsch DD 5.1\n\
+\n\
+Mehrkanalton:\n\
+Dolby Digital 5.1\n\
+\n\
+EAN:\n\
+4013549871105',
+			'runtime'			: 108,
+			'image'				: True,
+			'rating'			: False
+		}
+	}
