@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: preferences.py 810 2007-07-11 07:49:48Z mikej06 $'
+__revision__ = '$Id: preferences.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ from gettext import gettext as _
 import os
 import initialize
 import gutils
+import socket
 
 try:
 	import gtkspell
@@ -59,14 +60,40 @@ def show_preferences(self):
 		w['view_director'].set_active(False)
 	else:
 		w['view_director'].set_active(True)
+	# genre
+	if self.config.get('genre', True, 'mainlist') == False:
+		w['view_genre'].set_active(False)
+	else:
+		w['view_genre'].set_active(True)
+	# seen
+	if self.config.get('seen', True, 'mainlist') == False:
+		w['view_seen'].set_active(False)
+	else:
+		w['view_seen'].set_active(True)
+	# year
+	if self.config.get('year', True, 'mainlist') == False:
+		w['view_year'].set_active(False)
+	else:
+		w['view_year'].set_active(True)
+	# runtime
+	if self.config.get('runtime', True, 'mainlist') == False:
+		w['view_runtime'].set_active(False)
+	else:
+		w['view_runtime'].set_active(True)
 
 	# email reminder
 	if self.config.get('use_auth', False, section='mail') == False:
 		w['mail_use_auth'].set_active(False)
 	else:
 		w['mail_use_auth'].set_active(True)
+		
+	if self.config.get('mail_use_tls', False, section='mail') == False:
+		w['mail_use_tls'].set_active(False)
+	else:
+		w['mail_use_tls'].set_active(True)
 
 	w['mail_smtp_server'].set_text(self.config.get('smtp_server', 'localhost', section='mail'))
+	w['mail_smtp_port'].set_text(self.config.get('mail_smtp_port', '25', section='mail'))
 	w['mail_username'].set_text(self.config.get('username', '', section='mail'))
 	w['mail_password'].set_text(self.config.get('password', '', section='mail'))
 	w['mail_email'].set_text(self.config.get('email', 'griffith@localhost', section='mail'))
@@ -205,6 +232,26 @@ def save_preferences(self):
 		c.set('director', 'True', section='mainlist')
 	else:
 		c.set('director', 'False', section='mainlist')
+	# genre
+	if w['view_genre'].get_active():
+		c.set('genre', 'True', section='mainlist')
+	else:
+		c.set('genre', 'False', section='mainlist')
+	# seen
+	if w['view_seen'].get_active():
+		c.set('seen', 'True', section='mainlist')
+	else:
+		c.set('seen', 'False', section='mainlist')
+	# year
+	if w['view_year'].get_active():
+		c.set('year', 'True', section='mainlist')
+	else:
+		c.set('year', 'False', section='mainlist')
+	# runtime
+	if w['view_runtime'].get_active():
+		c.set('runtime', 'True', section='mainlist')
+	else:
+		c.set('runtime', 'False', section='mainlist')
 	
 	# sortby
 	if w['sortby'].get_active():
@@ -240,8 +287,14 @@ def save_preferences(self):
 	c['rating_image'] = str(w['rating_image'].get_active())
 
 	#defaults
-	c.set('media', self.media_ids[w['media'].get_active()], section='defaults')
-	c.set('vcodec', self.vcodecs_ids[w['vcodec'].get_active()], section='defaults')
+	media_id = self.media_ids[w['media'].get_active()]
+	if media_id is None:
+		media_id = 0
+	c.set('media', media_id, section='defaults')
+	vcodec_id = self.vcodecs_ids[w['vcodec'].get_active()]
+	if vcodec_id is None:
+		vcodec_id = 0
+	c.set('vcodec', vcodec_id, section='defaults')
 	c.set('condition', str(w['condition'].get_active()), section='defaults')
 	c.set('region', str(w['region'].get_active()), section='defaults')
 	c.set('layers', str(w['layers'].get_active()), section='defaults')
@@ -252,8 +305,15 @@ def save_preferences(self):
 		c.set('use_auth', True, section='mail')
 	else:
 		c.set('use_auth', False, section='mail')
+		
+	if w['mail_use_tls'].get_active():
+		c.set('mail_use_tls', True, section='mail')
+	else:
+		c.set('mail_use_tls', False, section='mail')
 
 	c.set('smtp_server', w['mail_smtp_server'].get_text(), section='mail')
+	c.set('mail_smtp_port', w['mail_smtp_port'].get_text(), section='mail')
+
 	c.set('username', w['mail_username'].get_text(), section='mail')
 	c.set('password', w['mail_password'].get_text(), section='mail')
 	c.set('email', w['mail_email'].get_text(), section='mail')
