@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: widgets.py 809 2007-07-09 20:47:46Z mikej06 $'
+__revision__ = '$Id: widgets.py 891 2007-12-16 21:13:53Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -182,17 +182,24 @@ def define_widgets(self, gladefile):
 		'view_o_title':		get('view_otitle'),
 		'view_title':		get('view_title'),
 		'view_director':	get('view_director'),
+		'view_genre':	get('view_genre'),
+		'view_seen':	get('view_seen'),
+		'view_year':	get('view_year'),
+		'view_runtime':	get('view_runtime'),
 		'rating_image':		get('rating_image'),
 		'spellchecker':		get('spellchecker_pref'),
 		'spell_notes':		get('spell_notes'),
 		'spell_plot':		get('spell_plot'),
 		'spell_lang':		get('spell_lang'),
+		'vbox_spellchecker':	get('vbox_spellchecker'),
 		'default_plugin':	get('default_plugin'),
 		'mail_smtp_server':	get('mail_smtp_server'),
 		'mail_use_auth':	get('mail_use_auth'),
 		'mail_username':	get('mail_username'),
 		'mail_password':	get('mail_password'),
 		'mail_email':		get('mail_email'),
+		'mail_smtp_port':		get('mail_smtp_port'),
+		'mail_use_tls':		get('mail_use_tls'),
 		'lang_name':		get('lang_name_combo'),
 		'tag_name':		get('tag_name_combo'),
 		'acodec_name':		get('acodec_name_combo'),
@@ -206,6 +213,7 @@ def define_widgets(self, gladefile):
 	}
 	self.widgets['preferences']['treeview'].connect('button_press_event', self.on_p_tree_button_press_event)
 	self.widgets['preferences']['window'].connect('delete_event', self.on_delete_event_p)
+	self.widgets['preferences']['spellchecker'].connect('toggled', self.on_cb_spellchecker_pref_toggled)
 	self.widgets['preferences']['window'].set_transient_for(self.widgets['window'])
 	#}}}
 
@@ -268,6 +276,7 @@ def define_widgets(self, gladefile):
 		'text':		get('filter_txt'),
 		'criteria':	get('filter_criteria'),
 		'collection':	get('f_col'),
+		'volume':	get('f_volume'),
 	}#}}}
 	
 	self.widgets['menu'] = {#{{{
@@ -304,10 +313,14 @@ def define_widgets(self, gladefile):
 	self.widgets['tooltips'].set_tip(self.widgets['preferences']['spell_lang'], _("Here you can define the desired language to use while spell checking some fields. Use you locale setting. For example, to use european portuguese spell checking enter 'pt'"))
 	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_smtp_server'], _("Use this entry to define the SMTP server you want to use to send e-mails. On *nix systems, 'localhost' should work. Alternatively, you can use your Internet Service Provider's SMTP server address."))
 	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_email'], _("This is the from e-mail address that should be used to all outgoing e-mail. You want to include your own e-mail address here probably."))
+	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_smtp_port'], _("Here you can define the smtp server port to use. If you want to use your gmail account service to send e-mails, try to enter '587' here. Default (and the most common one) is '25'"))
+	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_use_tls'], _("If you need TLS support, please check this checkbox. This is needed, for example, when using gmail service to send your reminder e-mails."))
 
 	# define handlers for general events
 	gladefile.signal_autoconnect({#{{{
 		'gtk_main_quit'				: self.destroy,
+		'on_window_state'			: self.on_window_state,
+		'on_configure'				: self.on_configure,
 		'on_about1_activate'			: self.about_dialog,
 		'on_quit1_activate'			: self.destroy,
 		'on_toolbar_quit_clicked'		: self.destroy,
@@ -340,7 +353,7 @@ def define_widgets(self, gladefile):
 		'on_people_activate'			: self.show_people_window,
 		'on_cancel_people_clicked'		: self.hide_people_window,
 		'on_filter_txt_changed'			: self.filter_txt,
-		'on_filter_criteria_changed'		: self.filter_txt,
+		'on_filter_criteria_changed'		: self.on_filter_criteria_changed,
 		'on_clear_filter_clicked'		: self.clear_filter,
 		'on_people_add_clicked'			: self.add_person,
 		'on_add_person_cancel_clicked'		: self.add_person_cancel,
@@ -404,6 +417,7 @@ def define_widgets(self, gladefile):
 		'on_am_remove_volume_button_clicked'	: self.remove_volume,
 		'on_am_remove_collection_button_clicked': self.remove_collection,
 		'on_f_col_changed'			: self.filter_collection,
+		'on_f_volume_changed'			: self.filter_volume,
 		'on_results_cancel_clicked'		: self.results_cancel_ck,
 		# languages
 		'on_lang_add_clicked'			: self.on_lang_add_clicked,
